@@ -19,6 +19,7 @@
 #include <iostream>
 #include <unistd.h>
 #include <vector>
+#include <map>
 
 #if defined(hidapi)
 	#include <locale>
@@ -374,12 +375,16 @@ bool LedKeyboard::commit() {
 		case KeyboardModel::g413:
 			return true; // Keyboard is non-transactional
 		case KeyboardModel::g410:
-    case KeyboardModel::g513:
+		case KeyboardModel::g512:
+		case KeyboardModel::g513:
 		case KeyboardModel::g610:
 		case KeyboardModel::g810:
 		case KeyboardModel::gpro:
 			data = { 0x11, 0xff, 0x0c, 0x5a };
 			break;
+		case KeyboardModel::g815:
+			data = { 0x11, 0xff, 0x10, 0x7f };
+			break;
 		case KeyboardModel::g910:
 			data = { 0x11, 0xff, 0x0f, 0x5d };
 			break;
@@ -399,135 +404,229 @@ bool LedKeyboard::setKeys(KeyValueArray keyValues) {
 	
 	bool retval = true;
 	
-	vector<vector<KeyValue>> SortedKeys = {
-		{}, // Logo AddressGroup
-		{}, // Indicators AddressGroup
-		{}, // Multimedia AddressGroup
-		{}, // GKeys AddressGroup
-		{} // Keys AddressGroup
-	};
+	vector<vector<KeyValue>> SortedKeys;
+	map<int32_t, vector<KeyValue>> KeyByColors;
+	map<int32_t, vector<KeyValue>>::iterator KeyByColorsIterator;
+	const uint8_t maxKeyPerColor = 13;
 	
-	for (uint8_t i = 0; i < keyValues.size(); i++) {
-		switch(static_cast<LedKeyboard::KeyAddressGroup>(static_cast<uint16_t>(keyValues[i].key) >> 8 )) {
-			case LedKeyboard::KeyAddressGroup::logo:
-				switch (currentDevice.model) {
-					case LedKeyboard::KeyboardModel::g610:
-					case LedKeyboard::KeyboardModel::g810:
-					case LedKeyboard::KeyboardModel::gpro:
-						if (SortedKeys[0].size() <= 1 && keyValues[i].key == LedKeyboard::Key::logo)
-							SortedKeys[0].push_back(keyValues[i]);
-						break;
-					case LedKeyboard::KeyboardModel::g910:
-						if (SortedKeys[0].size() <= 2) SortedKeys[0].push_back(keyValues[i]);
-						break;
-					default:
-						break;
-				}
-				break;
-			case LedKeyboard::KeyAddressGroup::indicators:
-				if (SortedKeys[1].size() <= 5) SortedKeys[1].push_back(keyValues[i]);
-				break;
-			case LedKeyboard::KeyAddressGroup::multimedia:
-				switch (currentDevice.model) {
-					case LedKeyboard::KeyboardModel::g610:
-					case LedKeyboard::KeyboardModel::g810:
-					case LedKeyboard::KeyboardModel::gpro:
-						if (SortedKeys[2].size() <= 5) SortedKeys[2].push_back(keyValues[i]);
-						break;
-					default:
-						break;
-				}
-				break;
-			case LedKeyboard::KeyAddressGroup::gkeys:
-				switch (currentDevice.model) {
-					case LedKeyboard::KeyboardModel::g910:
-						if (SortedKeys[3].size() <= 9) SortedKeys[3].push_back(keyValues[i]);
-						break;
-					default:
-						break;
-				}
-				break;
-			case LedKeyboard::KeyAddressGroup::keys:
-				switch (currentDevice.model) {
-					case LedKeyboard::KeyboardModel::g513:
-					case LedKeyboard::KeyboardModel::g610:
-					case LedKeyboard::KeyboardModel::g810:
-					case LedKeyboard::KeyboardModel::g910:
-					case LedKeyboard::KeyboardModel::gpro:
-						if (SortedKeys[4].size() <= 120) SortedKeys[4].push_back(keyValues[i]);
-						break;
-					case LedKeyboard::KeyboardModel::g410:
-						if (SortedKeys[4].size() <= 120)
-							if (keyValues[i].key < LedKeyboard::Key::num_lock || 
-							    keyValues[i].key > LedKeyboard::Key::num_dot)
-								SortedKeys[4].push_back(keyValues[i]);
-						break;
-					default:
-						break;
-				}
-				break;
-		}
-	}
-	
-	for (uint8_t kag = 0; kag < 5; kag++) {
-		
-		if (SortedKeys[kag].size() > 0) {
-			
-			uint8_t gi = 0;
-			while (gi < SortedKeys[kag].size()) {
-				
-				size_t data_size = 0;
-				byte_buffer_t data = {};
-				
-				switch (kag) {
-					case 0:
-						data_size = 20;
-						data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::logo);
-						break;
-					case 1:
-						data_size = 64;
-						data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::indicators);
-						break;
-					case 2:
-						data_size = 64;
-						data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::multimedia);
-						break;
-					case 3:
-						data_size = 64;
-						data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::gkeys);
-						break;
-					case 4:
-						data_size = 64;
-						data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::keys);
-						break;
-				}
-				
-				const uint8_t maxKeyCount = (data_size - 8) / 4;
-				
-				if (data.size() > 0) {
-					
-					for (uint8_t i = 0; i < maxKeyCount; i++) {
-						if (gi + i < SortedKeys[kag].size()) {
-							data.push_back(static_cast<uint8_t>(
-								static_cast<uint16_t>(SortedKeys[kag][gi+i].key) & 0x00ff));
-							data.push_back(SortedKeys[kag][gi+i].color.red);
-							data.push_back(SortedKeys[kag][gi+i].color.green);
-							data.push_back(SortedKeys[kag][gi+i].color.blue);
-						}
-					}
-					
-					data.resize(data_size, 0x00);
-					
-					if (retval) retval = sendDataInternal(data);
-					else sendDataInternal(data);
-					
-				}
-				
-				gi = gi + maxKeyCount;
+	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			for (uint8_t i = 0; i < keyValues.size(); i++) {
+				uint32_t colorkey = static_cast<uint32_t>(keyValues[i].color.red | keyValues[i].color.green << 8 | keyValues[i].color.blue << 16 );
+				if (KeyByColors.count(colorkey) == 0) KeyByColors.insert(pair<uint32_t, vector<KeyValue>>(colorkey, {}));
+				KeyByColors[colorkey].push_back(keyValues[i]);
 			}
 			
-		}
+			for (auto& x: KeyByColors) {
+				if (x.second.size() > 0) {
+					uint8_t gi = 0;
+					while (gi < x.second.size()) {
+						size_t data_size = 20;
+						byte_buffer_t data = { 0x11, 0xff, 0x10, 0x6c };
+						data.push_back(x.second[0].color.red);
+						data.push_back(x.second[0].color.green);
+						data.push_back(x.second[0].color.blue);
+						for (uint8_t i = 0; i < maxKeyPerColor; i++) {
+							if (gi + i < x.second.size()) {
+								switch (x.second[gi+i].key) {
+									case Key::logo2:
+									case Key::game:
+									case Key::caps:
+									case Key::scroll:
+									case Key::num:
+									case Key::stop:
+									case Key::g6:
+									case Key::g7:
+									case Key::g8:
+									case Key::g9:
+										break;
+									case Key::play:
+										data.push_back(0x9b);
+										break;
+									case Key::mute:
+										data.push_back(0x9c);
+										break;
+									case Key::next:
+										data.push_back(0x9d);
+										break;
+									case Key::prev:
+										data.push_back(0x9e);
+										break;
+									case Key::ctrl_left:
+									case Key::shift_left:
+									case Key::alt_left:
+									case Key::win_left:
+									case Key::ctrl_right:
+									case Key::shift_right:
+									case Key::alt_right:
+									case Key::win_right:
+										data.push_back((static_cast<uint8_t>(x.second[gi+i].key) & 0x00ff) - 0x78);
+										break;
+									default:
+										switch (static_cast<KeyAddressGroup>((static_cast<uint16_t>(x.second[gi+i].key) & 0xff00) / 0xff)) {
+											case KeyAddressGroup::logo:
+												data.push_back((static_cast<uint8_t>(x.second[gi+i].key) & 0x00ff) + 0xd1);
+												break;
+											case KeyAddressGroup::indicators:
+												data.push_back((static_cast<uint8_t>(x.second[gi+i].key) & 0x00ff) + 0x98);
+												break;
+											case KeyAddressGroup::gkeys:
+												data.push_back((static_cast<uint8_t>(x.second[gi+i].key) & 0x00ff) + 0xb3);
+												break;
+											case KeyAddressGroup::keys:
+												data.push_back((static_cast<uint8_t>(x.second[gi+i].key) & 0x00ff) - 0x03);
+												break;
+											default:
+												break;
+										}
+								}
+							}
+						}
+						
+						if (data.size() < data_size) data.push_back(0xff);
+						data.resize(data_size, 0x00);
+						if (retval) retval = sendDataInternal(data);
+						else sendDataInternal(data);
+						
+						gi = gi + maxKeyPerColor;
+					}
+				}
+			}
+			
+			break;
+		default:
+			SortedKeys = {
+				{}, // Logo AddressGroup
+				{}, // Indicators AddressGroup
+				{}, // Multimedia AddressGroup
+				{}, // GKeys AddressGroup
+				{} // Keys AddressGroup
+			};
+			
+			for (uint8_t i = 0; i < keyValues.size(); i++) {
+				switch(static_cast<LedKeyboard::KeyAddressGroup>(static_cast<uint16_t>(keyValues[i].key) >> 8 )) {
+					case LedKeyboard::KeyAddressGroup::logo:
+						switch (currentDevice.model) {
+							case LedKeyboard::KeyboardModel::g610:
+							case LedKeyboard::KeyboardModel::g810:
+							case LedKeyboard::KeyboardModel::gpro:
+								if (SortedKeys[0].size() <= 1 && keyValues[i].key == LedKeyboard::Key::logo)
+									SortedKeys[0].push_back(keyValues[i]);
+								break;
+							case LedKeyboard::KeyboardModel::g910:
+								if (SortedKeys[0].size() <= 2) SortedKeys[0].push_back(keyValues[i]);
+								break;
+							default:
+								break;
+						}
+						break;
+					case LedKeyboard::KeyAddressGroup::indicators:
+						if (SortedKeys[1].size() <= 5) SortedKeys[1].push_back(keyValues[i]);
+						break;
+					case LedKeyboard::KeyAddressGroup::multimedia:
+						switch (currentDevice.model) {
+							case LedKeyboard::KeyboardModel::g610:
+							case LedKeyboard::KeyboardModel::g810:
+							case LedKeyboard::KeyboardModel::gpro:
+								if (SortedKeys[2].size() <= 5) SortedKeys[2].push_back(keyValues[i]);
+								break;
+							default:
+								break;
+						}
+						break;
+					case LedKeyboard::KeyAddressGroup::gkeys:
+						switch (currentDevice.model) {
+							case LedKeyboard::KeyboardModel::g910:
+								if (SortedKeys[3].size() <= 9) SortedKeys[3].push_back(keyValues[i]);
+								break;
+							default:
+								break;
+						}
+						break;
+					case LedKeyboard::KeyAddressGroup::keys:
+						switch (currentDevice.model) {
+							case LedKeyboard::KeyboardModel::g512:
+							case LedKeyboard::KeyboardModel::g513:
+							case LedKeyboard::KeyboardModel::g610:
+							case LedKeyboard::KeyboardModel::g810:
+							case LedKeyboard::KeyboardModel::g910:
+							case LedKeyboard::KeyboardModel::gpro:
+								if (SortedKeys[4].size() <= 120) SortedKeys[4].push_back(keyValues[i]);
+								break;
+							case LedKeyboard::KeyboardModel::g410:
+								if (SortedKeys[4].size() <= 120)
+									if (keyValues[i].key < LedKeyboard::Key::num_lock ||
+										keyValues[i].key > LedKeyboard::Key::num_dot)
+										SortedKeys[4].push_back(keyValues[i]);
+								break;
+							default:
+								break;
+						}
+						break;
+				}
+			}
+			
+			for (uint8_t kag = 0; kag < 5; kag++) {
+				
+				if (SortedKeys[kag].size() > 0) {
+					
+					uint8_t gi = 0;
+					while (gi < SortedKeys[kag].size()) {
+						
+						size_t data_size = 0;
+						byte_buffer_t data = {};
+						
+						switch (kag) {
+							case 0:
+								data_size = 20;
+								data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::logo);
+								break;
+							case 1:
+								data_size = 64;
+								data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::indicators);
+								break;
+							case 2:
+								data_size = 64;
+								data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::multimedia);
+								break;
+							case 3:
+								data_size = 64;
+								data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::gkeys);
+								break;
+							case 4:
+								data_size = 64;
+								data = getKeyGroupAddress(LedKeyboard::KeyAddressGroup::keys);
+								break;
+						}
+						
+						const uint8_t maxKeyCount = (data_size - 8) / 4;
+						
+						if (data.size() > 0) {
+							
+							for (uint8_t i = 0; i < maxKeyCount; i++) {
+								if (gi + i < SortedKeys[kag].size()) {
+									data.push_back(static_cast<uint8_t>(
+										static_cast<uint16_t>(SortedKeys[kag][gi+i].key) & 0x00ff));
+									data.push_back(SortedKeys[kag][gi+i].color.red);
+									data.push_back(SortedKeys[kag][gi+i].color.green);
+									data.push_back(SortedKeys[kag][gi+i].color.blue);
+								}
+							}
+							
+							data.resize(data_size, 0x00);
+							
+							if (retval) retval = sendDataInternal(data);
+							else sendDataInternal(data);
+							
+						}
+						
+						gi = gi + maxKeyCount;
+					}
+					
+				}
+			}
 	}
+	
 	return retval;
 }
 
@@ -588,9 +687,11 @@ bool LedKeyboard::setAllKeys(LedKeyboard::Color color) {
 					NativeEffectStorage::none);
 			return true;
 		case KeyboardModel::g410:
-    case KeyboardModel::g513:
+		case KeyboardModel::g512:
+		case KeyboardModel::g513:
 		case KeyboardModel::g610:
 		case KeyboardModel::g810:
+		case KeyboardModel::g815:
 		case KeyboardModel::g910:
 		case KeyboardModel::gpro:
 			for (uint8_t i = 0; i < keyGroupLogo.size(); i++) keyValues.push_back({keyGroupLogo[i], color});
@@ -614,6 +715,17 @@ bool LedKeyboard::setAllKeys(LedKeyboard::Color color) {
 bool LedKeyboard::setMRKey(uint8_t value) {
 	LedKeyboard::byte_buffer_t data;
 	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			switch (value) {
+				case 0x00:
+				case 0x01:
+					data = { 0x11, 0xff, 0x0c, 0x0c, value };
+					data.resize(20, 0x00);
+					return sendDataInternal(data);
+				default:
+					break;
+			}
+			break;
 		case KeyboardModel::g910:
 			switch (value) {
 				case 0x00:
@@ -634,6 +746,24 @@ bool LedKeyboard::setMRKey(uint8_t value) {
 bool LedKeyboard::setMNKey(uint8_t value) {
 	LedKeyboard::byte_buffer_t data;
 	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			switch (value) {
+				case 0x01:
+                    data = { 0x11, 0xff, 0x0b, 0x1c, 0x01 };
+                    data.resize(20, 0x00);
+                    return sendDataInternal(data);
+                case 0x02:
+                    data = { 0x11, 0xff, 0x0b, 0x1c, 0x02 };
+                    data.resize(20, 0x00);
+                    return sendDataInternal(data);
+                case 0x03:
+                    data = { 0x11, 0xff, 0x0b, 0x1c, 0x04 };
+                    data.resize(20, 0x00);
+                    return sendDataInternal(data);
+				default:
+					break;
+			}
+			break;
 		case KeyboardModel::g910:
 			switch (value) {
 				case 0x00:
@@ -660,6 +790,17 @@ bool LedKeyboard::setMNKey(uint8_t value) {
 bool LedKeyboard::setGKeysMode(uint8_t value) {
 	LedKeyboard::byte_buffer_t data;
 	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			switch (value) {
+				case 0x00:
+				case 0x01:
+					data = { 0x11, 0xff, 0x0a, 0x2b, value };
+					data.resize(20, 0x00);
+					return sendDataInternal(data);
+				default:
+					break;
+			}
+			break;
 		case KeyboardModel::g910:
 			switch (value) {
 				case 0x00:
@@ -713,11 +854,22 @@ bool LedKeyboard::setStartupMode(StartupMode startupMode) {
 	return sendDataInternal(data);
 }
 
+bool LedKeyboard::setOnBoardMode(OnBoardMode onBoardMode) {
+	byte_buffer_t data;
+	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			data = { 0x11, 0xff, 0x11, 0x1a, static_cast<uint8_t>(onBoardMode) };
+			data.resize(20, 0x00);
+			return sendDataInternal(data);
+		default:
+			return false;
+	}
+}
 
 bool LedKeyboard::setNativeEffect(NativeEffect effect, NativeEffectPart part,
 				  std::chrono::duration<uint16_t, std::milli> period, Color color,
 				  NativeEffectStorage storage) {
-	uint8_t protocolByte = 0;
+	uint8_t protocolBytes[2] = {0x00, 0x00};
 	NativeEffectGroup effectGroup = static_cast<NativeEffectGroup>(static_cast<uint16_t>(effect) >> 8);
 
 	// NativeEffectPart::all is not in the device protocol, but an alias for both keys and logo, plus indicators
@@ -733,12 +885,15 @@ bool LedKeyboard::setNativeEffect(NativeEffect effect, NativeEffectPart part,
 				break;
 			case NativeEffectGroup::cycle:
 			case NativeEffectGroup::waves:
+			case NativeEffectGroup::ripple:
 				if (! setGroupKeys(
 					LedKeyboard::KeyGroup::indicators,
 					LedKeyboard::Color({0xff, 0xff, 0xff}))
 				) return false;
 				if (! commit()) return false;
 				break;
+			default:
+				break;
 		}
 		return (
 			setNativeEffect(effect, LedKeyboard::NativeEffectPart::keys, period, color, storage) &&
@@ -748,29 +903,33 @@ bool LedKeyboard::setNativeEffect(NativeEffect effect, NativeEffectPart part,
 	switch (currentDevice.model) {
 		case KeyboardModel::g213:
 		case KeyboardModel::g413:
-			protocolByte = 0x0c;
+			protocolBytes[0] = 0x0c;
+			protocolBytes[1] = 0x3c;
 			if (part == NativeEffectPart::logo) return true; //Does not have logo component
 			break;
 		case KeyboardModel::g410:
-    case KeyboardModel::g513:
+		case KeyboardModel::g512:
+		case KeyboardModel::g513:
 		case KeyboardModel::g610: // Unconfirmed
 		case KeyboardModel::g810:
 		case KeyboardModel::gpro:
-			protocolByte = 0x0d;
+			protocolBytes[0] = 0x0d;
+			protocolBytes[1] = 0x3c;
+			break;
+		case KeyboardModel::g815:
+			protocolBytes[0] = 0x0f;
+			protocolBytes[1] = 0x1c;
 			break;
 		case KeyboardModel::g910:
-			protocolByte = 0x10;
+			protocolBytes[0] = 0x10;
+			protocolBytes[1] = 0x3c;
 			break;
 		default:
 			return false;
 	}
 
-	if ((effectGroup == NativeEffectGroup::waves) && (part == NativeEffectPart::logo)) {
-		return setNativeEffect(NativeEffect::color, part, std::chrono::seconds(0), Color({0x00, 0xff, 0xff}), storage);
-	}
-
 	byte_buffer_t data = {
-		0x11, 0xff, protocolByte, 0x3c,
+		0x11, 0xff, protocolBytes[0], protocolBytes[1],
 		(uint8_t)part, static_cast<uint8_t>(effectGroup),
 		// color of static-color and breathing effects
 		color.red, color.green, color.blue,
@@ -787,7 +946,71 @@ bool LedKeyboard::setNativeEffect(NativeEffect effect, NativeEffectPart part,
 		0, // unused?
 		0, // unused?
 	};
-	return sendDataInternal(data);
+
+	byte_buffer_t setupData;
+	bool retval;
+	switch (currentDevice.model) {
+		case KeyboardModel::g815:
+			setupData = { 0x11, 0xff, 0x0f, 0x5c, 0x01, 0x03, 0x03 };
+			setupData.resize(20, 0x00);
+			retval = sendDataInternal(setupData);
+
+			data[16] = 0x01;
+
+			switch (part) {
+				case NativeEffectPart::keys:
+					data[4] = 0x01;
+
+					//Seems to conflict with a star-like effect on G410 and G810
+					switch (effect) {
+						case NativeEffect::ripple:
+							//Adjust periodicity
+							data[9]=0x00;
+							data[10]=period.count() >> 8 & 0xff;;
+							data[11]=period.count() & 0xff;
+							data[12]=0x00;
+							break;
+						default:
+							break;
+					}
+					break;
+				case NativeEffectPart::logo:
+					data[4] = 0x00;
+					switch (effect) {
+						case NativeEffect::breathing:
+							data[5]=0x03;
+							break;
+						case NativeEffect::cwave:
+						case NativeEffect::vwave:
+						case NativeEffect::hwave:
+							data[5]=0x02;
+							data[13]=0x64;
+							break;
+						case NativeEffect::waves:
+						case NativeEffect::cycle:
+							data[5]=0x02;
+							break;
+						case NativeEffect::ripple:
+						case NativeEffect::off:
+							data[5]=0x00;
+							break;
+						default:
+							data[5]=0x01;
+							break;
+					}
+					break;
+				default:
+					break;
+			}
+			break;
+		default: //Many devices may not support logo coloring for wave?
+			if ((effectGroup == NativeEffectGroup::waves) && (part == NativeEffectPart::logo)) {
+				return setNativeEffect(NativeEffect::color, part, std::chrono::seconds(0), Color({0x00, 0xff, 0xff}), storage);
+			}
+			break;
+	}
+	retval = sendDataInternal(data);
+	return retval;
 }
 
 
@@ -795,7 +1018,6 @@ bool LedKeyboard::sendDataInternal(byte_buffer_t &data) {
 	if (data.size() > 0) {
 		#if defined(hidapi)
 			if (! open(currentDevice.vendorID, currentDevice.productID, currentDevice.serialNumber)) return false;
-			data.insert(data.begin(), 0x00);
 			if (hid_write(m_hidHandle, const_cast<unsigned char*>(data.data()), data.size()) < 0) {
 				std::cout<<"Error: Can not write to hidraw, try with the libusb version"<<std::endl;
 				return false;
@@ -835,6 +1057,7 @@ LedKeyboard::byte_buffer_t LedKeyboard::getKeyGroupAddress(LedKeyboard::KeyAddre
 		case KeyboardModel::g413:
 		  return {}; // Device doesn't support per-key setting
 		case KeyboardModel::g410:
+		case KeyboardModel::g512:
 		case KeyboardModel::g513:
 		case KeyboardModel::gpro:
 			switch (keyAddressGroup) {
@@ -865,6 +1088,20 @@ LedKeyboard::byte_buffer_t LedKeyboard::getKeyGroupAddress(LedKeyboard::KeyAddre
 					return { 0x12, 0xff, 0x0c, 0x3a, 0x00, 0x01, 0x00, 0x0e };
 			}
 			break;
+		case KeyboardModel::g815:
+			switch (keyAddressGroup) {
+				case LedKeyboard::KeyAddressGroup::logo:
+					return { 0x11, 0xff, 0x10, 0x1c };
+				case LedKeyboard::KeyAddressGroup::indicators:
+					return { 0x11, 0xff, 0x10, 0x1c };
+				case LedKeyboard::KeyAddressGroup::gkeys:
+					return { 0x11, 0xff, 0x10, 0x1c };
+				case LedKeyboard::KeyAddressGroup::multimedia:
+					return { 0x11, 0xff, 0x10, 0x1c };
+				case LedKeyboard::KeyAddressGroup::keys:
+					return { 0x11, 0xff, 0x10, 0x1c };
+			}
+			break;
 		case KeyboardModel::g910:
 			switch (keyAddressGroup) {
 				case LedKeyboard::KeyAddressGroup::logo:
