@@ -32,9 +32,11 @@ namespace help {
 		if(cmdName == "g213-led") return KeyboardFeatures::g213;
 		else if(cmdName == "g410-led") return KeyboardFeatures::g410;
 		else if(cmdName == "g413-led") return KeyboardFeatures::g413;
+		else if(cmdName == "g512-led") return KeyboardFeatures::g512;
 		else if(cmdName == "g513-led") return KeyboardFeatures::g513;
 		else if(cmdName == "g610-led") return KeyboardFeatures::g610;
 		else if(cmdName == "g810-led") return KeyboardFeatures::g810;
+		else if(cmdName == "g815-led") return KeyboardFeatures::g815;
 		else if(cmdName == "g910-led") return KeyboardFeatures::g910;
 		else if(cmdName == "gpro-led") return KeyboardFeatures::gpro;
 		return KeyboardFeatures::all;
@@ -89,6 +91,10 @@ namespace help {
 			cout<<"  --startup-mode {startup mode}\t\tSet startup mode"<<endl;
 			cout<<endl;
 		}
+		if((features | KeyboardFeatures::onboardmode) == features) {
+			cout<<"  --on-board-mode {on-board mode}\t\tSet on-board mode"<<endl;
+			cout<<endl;
+		}
 		cout<<"  --list-keyboards \t\t\tList connected keyboards"<<endl;
 		cout<<"  --print-device\t\t\tPrint device information for the keyboard"<<endl;
 		cout<<endl;
@@ -119,6 +125,7 @@ namespace help {
 		if((features | KeyboardFeatures::setgroup) == features)
 			cout<<"  group values :\t\t\tlogo, indicators, fkeys, ... (use --help-keys for more detail)"<<endl;
 		cout<<"  startup mode :\t\t\twave, color"<<endl;
+		cout<<"  on-board mode :\t\t\tboard, software"<<endl;
 		cout<<endl;
 	}
 	
@@ -323,6 +330,9 @@ namespace help {
 		if((features | KeyboardFeatures::poweronfx) == features)
 			cout<<cmdName<<" --startup-mode color          # Set keyboard power on effect"<<endl;
 		cout<<endl;
+		if((features | KeyboardFeatures::onboardmode) == features)
+			cout<<cmdName<<" --on-board-mode color          # Set keyboard power on effect"<<endl;
+		cout<<endl;
 		if((features | KeyboardFeatures::commit) == features) {
 			cout<<"Samples with no commit :"<<endl;
 			if((features | KeyboardFeatures::setall) == features)
