@@ -27,15 +27,22 @@ namespace utils {
 	std::string getCmdName(std::string cmd) {
 		return cmd.substr(cmd.find_last_of("/\\") + 1);
 	}
-	
-	
-	
+
+
+
 	bool parseStartupMode(std::string val, LedKeyboard::StartupMode &startupMode) {
 		if (val == "wave") startupMode = LedKeyboard::StartupMode::wave;
 		else if (val == "color") startupMode = LedKeyboard::StartupMode::color;
 		else return false;
 		return true;
 	}
+
+	bool parseOnBoardMode(std::string val, LedKeyboard::OnBoardMode &onBoardMode) {
+		if (val == "software") onBoardMode = LedKeyboard::OnBoardMode ::software;
+		else if (val == "board") onBoardMode = LedKeyboard::OnBoardMode::board;
+		else return false;
+		return true;
+	}
 	
 	bool parseNativeEffect(std::string val, LedKeyboard::NativeEffect &nativeEffect) {
 		if (val == "color") nativeEffect = LedKeyboard::NativeEffect::color;
